@@ -18,7 +18,7 @@
 #' mark:::mapply0(foo, x)
 #' @noRd
 mapply0 <- function(FUN, params = NULL, ...) { # nolint: object_name_linter.
-  params <- c(params,  list(...))
+  params <- c(params,  rlang::list2(...))
 
   FUN <- match.fun(FUN) # nolint: object_name_linter.
   n <- max(lengths(params))
