@@ -18,8 +18,12 @@
 #' @export
 sort_by <- function(x, by, ...) {
   if (!is_atomic0(x) || !is_atomic0(by)) {
-    stop("`x` and `by` must be atomic vectors", call. = FALSE)
+    stop(cond_sort_by_atomic())
   }
 
   x[order(by, ...)]
 }
+
+cond_sort_by_atomic <- function() {
+  new_condition("`x` and `by` must be atomic vectors", "sort_by_atomic")
+}
